==> breeze_website_builder_5.4.54.tar.gz: manage/js/manage_menu.js <==
/////////////////////////////////////////////
// Manage Menu /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 7/1/2013	ELL

var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
var popup_msg = new PopupMsg(param_array);

function SubmitUpdateType()
{
	alert("You will need to re-assign this menu to the border area to complete the conversion.");
	document.forms["frmUpdateMenuType"].submit();
}

function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_menu", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function DeleteConfirm()
{
	popup_msg.top_offset = 0;
	popup_msg.left_offset = 300;
	popup_msg.popup_msg_type = 3;
	popup_msg.popup_btn_cnt = 2;
	popup_msg.popup_msg_cell = "Are you sure you want to delete the <b>" + document.getElementById("selectMenuDelete").value + "</b> menu?";
	popup_msg.popup_button_2_span = "Yes";
	popup_msg.popup_button_1_span = "No";
	popup_msg.popup_timeout = -1;
	popup_msg.ShowPopupMsg();
	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenu(); };
	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
}

function DeleteMenu()
{
	var menu = document.getElementById("selectMenuDelete").value;
	HidePopupMsg();
	var url = "delete_menu.php?menu=" + menu;
	window.location = url;
}

function UpdateMenuType(nFrmIndex)
{
	var sFormName = "frmAssign" + nFrmIndex;
	var frmElement = document.forms[sFormName]
	var cntMenuSelect = frmElement.elements["menu_name"];
	var cntMenuType = frmElement.elements["menu_type"];
	var nSelectedIndex = cntMenuSelect.selectedIndex;
	var sMenuSting = cntMenuSelect.options[nSelectedIndex].text;
	// menu_type = 1 ---> JavaScript, menu_type = 0 ---> CSS
	var nResult = sMenuSting.indexOf("(JavaScript)");
	if (nResult > 0)
		cntMenuType.value = 1;
	else
		cntMenuType.value = 0;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////
function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {

}

function DisplayNotSavedMessage(btn)	{
	// Needed to complete call when deleting unsaved page.
	window.parent.SetWorkSavedNotSaved(true);
	window.parent.next_btn = btn;
	window.parent.DoNextClick();
}

==> breeze_website_builder_6.1.20.tar.gz: manage/js/manage_menu.js <==
/////////////////////////////////////////////
// Manage Menu /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 7/1/2013	ELL

var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
var popup_msg = new PopupMsg(param_array);

window.parent.document.title = document.title;

function SubmitUpdateType()
{
	alert(MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG);
	document.forms["frmUpdateMenuType"].submit();
}

function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_menu", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function DeleteConfirm()
{
	popup_msg.top_offset = 0;
	popup_msg.left_offset = 300;
	popup_msg.popup_msg_type = 3;
	popup_msg.popup_btn_cnt = 2;
	popup_msg.popup_msg_cell = MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG + " <b>" + document.getElementById("selectMenuDelete").value + "</b> " + MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG;
	popup_msg.popup_button_2_span = YES_WORD;
	popup_msg.popup_button_1_span = NO_WORD;
	popup_msg.popup_timeout = -1;
	popup_msg.ShowPopupMsg();
	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenu(); };
	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
}

function DeleteMenu()
{
	var menu = document.getElementById("selectMenuDelete").value;
	HidePopupMsg();
	var url = "delete_menu.php?menu=" + menu;
	window.location = url;
}

function UpdateMenuType(nFrmIndex)
{
	var sFormName = "frmAssign" + nFrmIndex;
	var frmElement = document.forms[sFormName]
	var cntMenuSelect = frmElement.elements["menu_name"];
	var cntMenuType = frmElement.elements["menu_type"];
	var nSelectedIndex = cntMenuSelect.selectedIndex;
	var sMenuSting = cntMenuSelect.options[nSelectedIndex].text;
	// menu_type = 1 ---> JavaScript, menu_type = 0 ---> CSS
	var nResult = sMenuSting.indexOf("(JavaScript)");
	if (nResult > 0)
		cntMenuType.value = 1;
	else
		cntMenuType.value = 0;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////
function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {

}

function DisplayNotSavedMessage(btn)	{
	// Needed to complete call when deleting unsaved page.
	window.parent.SetWorkSavedNotSaved(true);
	window.parent.next_btn = btn;
	window.parent.DoNextClick();
}
